log

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddCore

func AddCore(logger *zap.SugaredLogger, core zapcore.Core) *zap.SugaredLogger

AddCore attaches an additional core to a logger and returns the augmented logger. Used by the gateway log broadcaster to fan out log lines to SSE clients.

func Init

func Init(level, consoleLevel, file string) (*zap.SugaredLogger, error)

Init creates a new *zap.SugaredLogger from config values. consoleLevel overrides the console sink's level; if empty it defaults to level.

Types

This section is empty.

Jump to