Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LoadHeartbeatMD ¶
LoadHeartbeatMD reads {workspace}/HEARTBEAT.md and returns its content. Used for lightweight cron/heartbeat bootstrap context. Returns empty string if the file does not exist or workspace is empty.
func LoadMemoryMD ¶
LoadMemoryMD reads {workspace}/MEMORY.md and returns its content. Returns empty string if the file does not exist or workspace is empty.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.