Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddCore ¶
func AddCore(logger *zap.SugaredLogger, core zapcore.Core) *zap.SugaredLogger
AddCore attaches an additional core to a logger and returns the augmented logger. Used by the gateway log broadcaster to fan out log lines to SSE clients.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.